# CONFIDENTIAL. (C) 2022 Cadence Design Systems, Inc. (Cadence)
# All rights reserved.
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO CADENCE
# AND IS SUBJECT TO THE FULL PROTECTION OF COPYRIGHT AND TRADE SECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from Cadence is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact Cadence at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")


def swig_import_helper():
    from os.path import dirname
    import importlib.util
    import importlib.abc

    spec = importlib.machinery.PathFinder().find_spec("_oechem", [dirname(__file__)])

    if spec is None:
        # OpenEye Import Statements
        spec = importlib.machinery.PathFinder().find_spec("libs",[dirname(__file__)])
    libs = importlib.util.module_from_spec(spec)

    import sys
    sys.modules[spec.name] = libs
    spec.loader.exec_module(libs)

    assert not sys.platform.startswith('win')

    _oezap = libs.OEGetModule('_oezap2451')
    return _oezap

_oezap = swig_import_helper()
del swig_import_helper

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import weakref

import openeye.oechem as oechem
OEAreaMethod_Undefined = _oezap.OEAreaMethod_Undefined

OEAreaMethod_Gaussian = _oezap.OEAreaMethod_Gaussian

OEAreaMethod_Discrete = _oezap.OEAreaMethod_Discrete


OEAreaMethod_Default = OEAreaMethod_Gaussian

OEZapDielectricModel_Gaussian = _oezap.OEZapDielectricModel_Gaussian

OEZapDielectricModel_Molecular = _oezap.OEZapDielectricModel_Molecular


OEZapDielectricModel_Default = OEZapDielectricModel_Gaussian

class OESimpleBindResultsIter(object):
    r"""Proxy of C++ OESystem::OEIterBase< OEPB::OESimpleBindResults > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _oezap.delete_OESimpleBindResultsIter

    def Copy(self) -> "OESystem::OEIterBase< OEPB::OESimpleBindResults > *":
        r"""Copy(OESimpleBindResultsIter self) -> OESimpleBindResultsIter"""
        return _oezap.OESimpleBindResultsIter_Copy(self)

    def Push(self, ib: "OESimpleBindResultsIter") -> "OESystem::OEIterBase< OEPB::OESimpleBindResults > *":
        r"""Push(OESimpleBindResultsIter self, OESimpleBindResultsIter ib) -> OESimpleBindResultsIter"""
        return _oezap.OESimpleBindResultsIter_Push(self, ib)

    def ToFirst(self) -> "OESystem::OEIterBase< OEPB::OESimpleBindResults > &":
        r"""ToFirst(OESimpleBindResultsIter self) -> OESimpleBindResultsIter"""
        return _oezap.OESimpleBindResultsIter_ToFirst(self)

    def ToLast(self) -> "OESystem::OEIterBase< OEPB::OESimpleBindResults > &":
        r"""ToLast(OESimpleBindResultsIter self) -> OESimpleBindResultsIter"""
        return _oezap.OESimpleBindResultsIter_ToLast(self)

    def __ref__(self) -> "OEPB::OESimpleBindResults &":
        r"""__ref__(OESimpleBindResultsIter self) -> OESimpleBindResults"""
        return _oezap.OESimpleBindResultsIter___ref__(self)

    def IsValid(self):
      return _oezap.OESimpleBindResultsIter___nonzero__(self)



# Register OESimpleBindResultsIter in _oezap:
_oezap.OESimpleBindResultsIter_swigregister(OESimpleBindResultsIter)

class OEBindResultsIter(object):
    r"""Proxy of C++ OESystem::OEIterBase< OEPB::OEBindResults > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _oezap.delete_OEBindResultsIter

    def Copy(self) -> "OESystem::OEIterBase< OEPB::OEBindResults > *":
        r"""Copy(OEBindResultsIter self) -> OEBindResultsIter"""
        return _oezap.OEBindResultsIter_Copy(self)

    def Push(self, ib: "OEBindResultsIter") -> "OESystem::OEIterBase< OEPB::OEBindResults > *":
        r"""Push(OEBindResultsIter self, OEBindResultsIter ib) -> OEBindResultsIter"""
        return _oezap.OEBindResultsIter_Push(self, ib)

    def ToFirst(self) -> "OESystem::OEIterBase< OEPB::OEBindResults > &":
        r"""ToFirst(OEBindResultsIter self) -> OEBindResultsIter"""
        return _oezap.OEBindResultsIter_ToFirst(self)

    def ToLast(self) -> "OESystem::OEIterBase< OEPB::OEBindResults > &":
        r"""ToLast(OEBindResultsIter self) -> OEBindResultsIter"""
        return _oezap.OEBindResultsIter_ToLast(self)

    def __ref__(self) -> "OEPB::OEBindResults &":
        r"""__ref__(OEBindResultsIter self) -> OEBindResults"""
        return _oezap.OEBindResultsIter___ref__(self)

    def IsValid(self):
      return _oezap.OEBindResultsIter___nonzero__(self)



# Register OEBindResultsIter in _oezap:
_oezap.OEBindResultsIter_swigregister(OEBindResultsIter)

class OESimpleBindResults(object):
    r"""Proxy of C++ OEPB::OESimpleBindResults class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetUnboundProteinZapEnergy(self) -> "float":
        r"""GetUnboundProteinZapEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetUnboundProteinZapEnergy(self)

    def GetUnboundLigandZapEnergy(self) -> "float":
        r"""GetUnboundLigandZapEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetUnboundLigandZapEnergy(self)

    def GetBoundProteinZapEnergy(self) -> "float":
        r"""GetBoundProteinZapEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetBoundProteinZapEnergy(self)

    def GetBoundLigandZapEnergy(self) -> "float":
        r"""GetBoundLigandZapEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetBoundLigandZapEnergy(self)

    def GetComplexZapEnergy(self) -> "float":
        r"""GetComplexZapEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetComplexZapEnergy(self)

    def GetZapEnergy(self) -> "float":
        r"""GetZapEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetZapEnergy(self)

    def GetUnboundProteinAreaEnergy(self) -> "float":
        r"""GetUnboundProteinAreaEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetUnboundProteinAreaEnergy(self)

    def GetUnboundLigandAreaEnergy(self) -> "float":
        r"""GetUnboundLigandAreaEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetUnboundLigandAreaEnergy(self)

    def GetBoundProteinAreaEnergy(self) -> "float":
        r"""GetBoundProteinAreaEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetBoundProteinAreaEnergy(self)

    def GetBoundLigandAreaEnergy(self) -> "float":
        r"""GetBoundLigandAreaEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetBoundLigandAreaEnergy(self)

    def GetComplexAreaEnergy(self) -> "float":
        r"""GetComplexAreaEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetComplexAreaEnergy(self)

    def GetBuriedAreaEnergy(self) -> "float":
        r"""GetBuriedAreaEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetBuriedAreaEnergy(self)

    def GetBindingEnergy(self) -> "float":
        r"""GetBindingEnergy(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetBindingEnergy(self)

    def GetUnboundProteinArea(self) -> "float":
        r"""GetUnboundProteinArea(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetUnboundProteinArea(self)

    def GetUnboundLigandArea(self) -> "float":
        r"""GetUnboundLigandArea(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetUnboundLigandArea(self)

    def GetBoundProteinArea(self) -> "float":
        r"""GetBoundProteinArea(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetBoundProteinArea(self)

    def GetBoundLigandArea(self) -> "float":
        r"""GetBoundLigandArea(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetBoundLigandArea(self)

    def GetComplexArea(self) -> "float":
        r"""GetComplexArea(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetComplexArea(self)

    def GetBuriedArea(self) -> "float":
        r"""GetBuriedArea(OESimpleBindResults self) -> float"""
        return _oezap.OESimpleBindResults_GetBuriedArea(self)

    def GetConf(self, *args) -> "OEChem::OEConfBase const *":
        r"""
        GetConf(OESimpleBindResults self) -> OEConfBase
        GetConf(OESimpleBindResults self) -> OEConfBase
        """
        return _oezap.OESimpleBindResults_GetConf(self, *args)

    def Print(self, *args) -> "void":
        r"""
        Print(OESimpleBindResults self, oeostream ofs)
        Print(OESimpleBindResults self, OEErrorHandler log)
        """
        return _oezap.OESimpleBindResults_Print(self, *args)

    def __init__(self, *args):
        r"""
        __init__(OESimpleBindResults self) -> OESimpleBindResults
        __init__(OESimpleBindResults self, OESimpleBindResults arg2) -> OESimpleBindResults
        """
        _oezap.OESimpleBindResults_swiginit(self, _oezap.new_OESimpleBindResults(*args))
    __swig_destroy__ = _oezap.delete_OESimpleBindResults

# Register OESimpleBindResults in _oezap:
_oezap.OESimpleBindResults_swigregister(OESimpleBindResults)

class OEBindResults(OESimpleBindResults):
    r"""Proxy of C++ OEPB::OEBindResults class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Print(self, *args) -> "void":
        r"""
        Print(OEBindResults self, oeostream ofs)
        Print(OEBindResults self, OEErrorHandler log)
        """
        return _oezap.OEBindResults_Print(self, *args)

    def GetUnboundProteinCoulombEnergy(self) -> "float":
        r"""GetUnboundProteinCoulombEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetUnboundProteinCoulombEnergy(self)

    def GetUnboundLigandCoulombEnergy(self) -> "float":
        r"""GetUnboundLigandCoulombEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetUnboundLigandCoulombEnergy(self)

    def GetBoundProteinCoulombEnergy(self) -> "float":
        r"""GetBoundProteinCoulombEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetBoundProteinCoulombEnergy(self)

    def GetBoundLigandCoulombEnergy(self) -> "float":
        r"""GetBoundLigandCoulombEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetBoundLigandCoulombEnergy(self)

    def GetComplexCoulombEnergy(self) -> "float":
        r"""GetComplexCoulombEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetComplexCoulombEnergy(self)

    def GetCoulombEnergy(self) -> "float":
        r"""GetCoulombEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetCoulombEnergy(self)

    def GetAnalyticCoulombicBindingEnergy(self) -> "float":
        r"""GetAnalyticCoulombicBindingEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetAnalyticCoulombicBindingEnergy(self)

    def GetProteinDesolvationEnergy(self) -> "float":
        r"""GetProteinDesolvationEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetProteinDesolvationEnergy(self)

    def GetLigandDesolvationEnergy(self) -> "float":
        r"""GetLigandDesolvationEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetLigandDesolvationEnergy(self)

    def GetDesolvationEnergy(self) -> "float":
        r"""GetDesolvationEnergy(OEBindResults self) -> float"""
        return _oezap.OEBindResults_GetDesolvationEnergy(self)

    def __init__(self, *args):
        r"""
        __init__(OEBindResults self) -> OEBindResults
        __init__(OEBindResults self, OEBindResults arg2) -> OEBindResults
        """
        _oezap.OEBindResults_swiginit(self, _oezap.new_OEBindResults(*args))
    __swig_destroy__ = _oezap.delete_OEBindResults

# Register OEBindResults in _oezap:
_oezap.OEBindResults_swigregister(OEBindResults)

class OEBind(object):
    r"""Proxy of C++ OEPB::OEBind class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(OEBind self) -> OEBind
        __init__(OEBind self, OEMolBase protein) -> OEBind
        __init__(OEBind self, OEBind rhs) -> OEBind
        """
        _oezap.OEBind_swiginit(self, _oezap.new_OEBind(*args))
    __swig_destroy__ = _oezap.delete_OEBind

    def SetProtein(self, protein: "OEMolBase") -> "bool":
        r"""SetProtein(OEBind self, OEMolBase protein) -> bool"""
        return _oezap.OEBind_SetProtein(self, protein)

    def SimpleBind(self, *args) -> "bool":
        r"""
        SimpleBind(OEBind self, OEMCMolBase ligand) -> OESimpleBindResultsIter
        SimpleBind(OEBind self, OEMolBase ligand, OESimpleBindResults results) -> bool
        """
        return _oezap.OEBind_SimpleBind(self, *args)

    def Bind(self, *args) -> "bool":
        r"""
        Bind(OEBind self, OEMCMolBase ligand) -> OEBindResultsIter
        Bind(OEBind self, OEMolBase ligand, OEBindResults results) -> bool
        """
        return _oezap.OEBind_Bind(self, *args)

    def GetZap(self, *args) -> "OEPB::OEZap const &":
        r"""
        GetZap(OEBind self) -> OEZap
        GetZap(OEBind self) -> OEZap
        """
        return _oezap.OEBind_GetZap(self, *args)

    def SetZap(self, zap: "OEZap") -> "bool":
        r"""SetZap(OEBind self, OEZap zap) -> bool"""
        return _oezap.OEBind_SetZap(self, zap)

# Register OEBind in _oezap:
_oezap.OEBind_swigregister(OEBind)


def OEZapBind(*args) -> "bool":
    r"""
    OEZapBind(OEMolBase protein, OEMolBase ligand, OESimpleBindResults results) -> bool
    OEZapBind(OEMolBase protein, OEMolBase ligand, OEBindResults results) -> bool
    """
    return _oezap.OEZapBind(*args)
class OEZap(object):
    r"""Proxy of C++ OEPB::OEZap class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(OEZap self) -> OEZap
        __init__(OEZap self, OEZap rhs) -> OEZap
        """
        _oezap.OEZap_swiginit(self, _oezap.new_OEZap(*args))
    __swig_destroy__ = _oezap.delete_OEZap

    def SetMolecule(self, mol: "OEMolBase") -> "bool":
        r"""SetMolecule(OEZap self, OEMolBase mol) -> bool"""
        return _oezap.OEZap_SetMolecule(self, mol)

    def GetMolecule(self) -> "OEChem::OEMolBase const *":
        r"""GetMolecule(OEZap self) -> OEMolBase"""
        return _oezap.OEZap_GetMolecule(self)

    def SetFocusTarget(self, mol: "OEMolBase") -> "bool":
        r"""SetFocusTarget(OEZap self, OEMolBase mol) -> bool"""
        return _oezap.OEZap_SetFocusTarget(self, mol)

    def GetFocusTarget(self) -> "OEChem::OEMolBase const *":
        r"""GetFocusTarget(OEZap self) -> OEMolBase"""
        return _oezap.OEZap_GetFocusTarget(self)

    def IsFocusTargetSet(self) -> "bool":
        r"""IsFocusTargetSet(OEZap self) -> bool"""
        return _oezap.OEZap_IsFocusTargetSet(self)

    def ClearFocusTarget(self) -> "void":
        r"""ClearFocusTarget(OEZap self)"""
        return _oezap.OEZap_ClearFocusTarget(self)

    def CalcSolvationEnergy(self) -> "float":
        r"""CalcSolvationEnergy(OEZap self) -> float"""
        return _oezap.OEZap_CalcSolvationEnergy(self)

    def CalcPotentialGrid(self, grid: "OESystem::OEScalarGrid &") -> "bool":
        r"""CalcPotentialGrid(OEZap self, OESystem::OEScalarGrid & grid) -> bool"""
        return _oezap.OEZap_CalcPotentialGrid(self, grid)

    def CalcAtomPotentials(self, pot: "float *", no_grid: "bool"=False) -> "bool":
        r"""CalcAtomPotentials(OEZap self, float * pot, bool no_grid=False) -> bool"""
        return _oezap.OEZap_CalcAtomPotentials(self, pot, no_grid)

    def CalcForces(self, forces: "float *") -> "bool":
        r"""CalcForces(OEZap self, float * forces) -> bool"""
        return _oezap.OEZap_CalcForces(self, forces)

    def SetInnerDielectric(self, epsin: "float") -> "bool":
        r"""SetInnerDielectric(OEZap self, float epsin) -> bool"""
        return _oezap.OEZap_SetInnerDielectric(self, epsin)

    def SetOuterDielectric(self, epsout: "float") -> "bool":
        r"""SetOuterDielectric(OEZap self, float epsout) -> bool"""
        return _oezap.OEZap_SetOuterDielectric(self, epsout)

    def SetSaltConcentration(self, conc: "float") -> "bool":
        r"""SetSaltConcentration(OEZap self, float conc) -> bool"""
        return _oezap.OEZap_SetSaltConcentration(self, conc)

    def SetProbeRadius(self, radius: "float") -> "bool":
        r"""SetProbeRadius(OEZap self, float radius) -> bool"""
        return _oezap.OEZap_SetProbeRadius(self, radius)

    def SetError(self, zaperr: "float") -> "bool":
        r"""SetError(OEZap self, float zaperr) -> bool"""
        return _oezap.OEZap_SetError(self, zaperr)

    def SetIterations(self, iters: "unsigned int") -> "bool":
        r"""SetIterations(OEZap self, unsigned int iters) -> bool"""
        return _oezap.OEZap_SetIterations(self, iters)

    def SetDielectricModel(self, model: "unsigned int") -> "bool":
        r"""SetDielectricModel(OEZap self, unsigned int model) -> bool"""
        return _oezap.OEZap_SetDielectricModel(self, model)

    def SetVerbose(self, verbose: "bool") -> "void":
        r"""SetVerbose(OEZap self, bool verbose)"""
        return _oezap.OEZap_SetVerbose(self, verbose)

    def GetInnerDielectric(self) -> "float":
        r"""GetInnerDielectric(OEZap self) -> float"""
        return _oezap.OEZap_GetInnerDielectric(self)

    def GetOuterDielectric(self) -> "float":
        r"""GetOuterDielectric(OEZap self) -> float"""
        return _oezap.OEZap_GetOuterDielectric(self)

    def GetSaltConcentration(self) -> "float":
        r"""GetSaltConcentration(OEZap self) -> float"""
        return _oezap.OEZap_GetSaltConcentration(self)

    def GetProbeRadius(self) -> "float":
        r"""GetProbeRadius(OEZap self) -> float"""
        return _oezap.OEZap_GetProbeRadius(self)

    def GetError(self) -> "float":
        r"""GetError(OEZap self) -> float"""
        return _oezap.OEZap_GetError(self)

    def GetIterations(self) -> "unsigned int":
        r"""GetIterations(OEZap self) -> unsigned int"""
        return _oezap.OEZap_GetIterations(self)

    def GetDielectricModel(self) -> "unsigned int":
        r"""GetDielectricModel(OEZap self) -> unsigned int"""
        return _oezap.OEZap_GetDielectricModel(self)

    def GetVerbose(self) -> "bool":
        r"""GetVerbose(OEZap self) -> bool"""
        return _oezap.OEZap_GetVerbose(self)

    def SetGridSpacing(self, spacing: "float") -> "bool":
        r"""SetGridSpacing(OEZap self, float spacing) -> bool"""
        return _oezap.OEZap_SetGridSpacing(self, spacing)

    def SetBoundarySpacing(self, spacing: "float") -> "bool":
        r"""SetBoundarySpacing(OEZap self, float spacing) -> bool"""
        return _oezap.OEZap_SetBoundarySpacing(self, spacing)

    def GetGridSpacing(self) -> "float":
        r"""GetGridSpacing(OEZap self) -> float"""
        return _oezap.OEZap_GetGridSpacing(self)

    def GetBoundarySpacing(self) -> "float":
        r"""GetBoundarySpacing(OEZap self) -> float"""
        return _oezap.OEZap_GetBoundarySpacing(self)

# Register OEZap in _oezap:
_oezap.OEZap_swigregister(OEZap)


def OECoulombicSelfEnergy(mol: "OEMolBase", D: "float") -> "float":
    r"""OECoulombicSelfEnergy(OEMolBase mol, float D) -> float"""
    return _oezap.OECoulombicSelfEnergy(mol, D)

def OECoulombicAtomPotentials(mol: "OEMolBase", D: "float", apot: "float *") -> "bool":
    r"""OECoulombicAtomPotentials(OEMolBase mol, float D, float * apot) -> bool"""
    return _oezap.OECoulombicAtomPotentials(mol, D, apot)

def OECalculateCoulombicBinding(protein: "OEMolBase", ligand: "OEMolBase", dielectric: "float") -> "float":
    r"""OECalculateCoulombicBinding(OEMolBase protein, OEMolBase ligand, float dielectric) -> float"""
    return _oezap.OECalculateCoulombicBinding(protein, ligand, dielectric)
class OEArea(object):
    r"""Proxy of C++ OEPB::OEArea class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(OEArea self) -> OEArea
        __init__(OEArea self, OEArea arg2) -> OEArea
        """
        _oezap.OEArea_swiginit(self, _oezap.new_OEArea(*args))
    __swig_destroy__ = _oezap.delete_OEArea

    def GetArea(self, *args) -> "bool":
        r"""
        GetArea(OEArea self, OEMolBase mol) -> float
        GetArea(OEArea self, OEMolBase mol, float * atomArea) -> bool
        """
        return _oezap.OEArea_GetArea(self, *args)

    def SetMethod(self, method: "unsigned int const") -> "bool":
        r"""SetMethod(OEArea self, unsigned int const method) -> bool"""
        return _oezap.OEArea_SetMethod(self, method)

    def GetMethod(self) -> "unsigned int":
        r"""GetMethod(OEArea self) -> unsigned int"""
        return _oezap.OEArea_GetMethod(self)

    def SetUseHydrogens(self, state: "bool") -> "bool":
        r"""SetUseHydrogens(OEArea self, bool state) -> bool"""
        return _oezap.OEArea_SetUseHydrogens(self, state)

    def GetUseHydrogens(self) -> "bool":
        r"""GetUseHydrogens(OEArea self) -> bool"""
        return _oezap.OEArea_GetUseHydrogens(self)

# Register OEArea in _oezap:
_oezap.OEArea_swigregister(OEArea)

class OEET(object):
    r"""Proxy of C++ OEPB::OEET class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(OEET self, float dielectric=80.0) -> OEET
        __init__(OEET self, OEET rhs) -> OEET
        """
        _oezap.OEET_swiginit(self, _oezap.new_OEET(*args))
    __swig_destroy__ = _oezap.delete_OEET

    def SetRefMol(self, mol: "OEMolBase") -> "bool":
        r"""SetRefMol(OEET self, OEMolBase mol) -> bool"""
        return _oezap.OEET_SetRefMol(self, mol)

    def Tanimoto(self, mol: "OEMolBase") -> "float":
        r"""Tanimoto(OEET self, OEMolBase mol) -> float"""
        return _oezap.OEET_Tanimoto(self, mol)

    def SetDielectric(self, d: "float") -> "void":
        r"""SetDielectric(OEET self, float d)"""
        return _oezap.OEET_SetDielectric(self, d)

    def SetInnerDielectric(self, d: "float") -> "void":
        r"""SetInnerDielectric(OEET self, float d)"""
        return _oezap.OEET_SetInnerDielectric(self, d)

    def SetSaltConcentration(self, conc: "float") -> "void":
        r"""SetSaltConcentration(OEET self, float conc)"""
        return _oezap.OEET_SetSaltConcentration(self, conc)

    def SetInnerMask(self, f: "float") -> "void":
        r"""SetInnerMask(OEET self, float f)"""
        return _oezap.OEET_SetInnerMask(self, f)

    def SetOuterMask(self, f: "float") -> "void":
        r"""SetOuterMask(OEET self, float f)"""
        return _oezap.OEET_SetOuterMask(self, f)

    def SetJoin(self, j: "bool") -> "void":
        r"""SetJoin(OEET self, bool j)"""
        return _oezap.OEET_SetJoin(self, j)

    def SetGridSpacing(self, f: "float") -> "void":
        r"""SetGridSpacing(OEET self, float f)"""
        return _oezap.OEET_SetGridSpacing(self, f)

    def SetGridBuffer(self, f: "float") -> "void":
        r"""SetGridBuffer(OEET self, float f)"""
        return _oezap.OEET_SetGridBuffer(self, f)

    def GetDielectric(self) -> "float":
        r"""GetDielectric(OEET self) -> float"""
        return _oezap.OEET_GetDielectric(self)

    def GetInnerDielectric(self) -> "float":
        r"""GetInnerDielectric(OEET self) -> float"""
        return _oezap.OEET_GetInnerDielectric(self)

    def GetSaltConcentration(self) -> "float":
        r"""GetSaltConcentration(OEET self) -> float"""
        return _oezap.OEET_GetSaltConcentration(self)

    def GetInnerMask(self) -> "float":
        r"""GetInnerMask(OEET self) -> float"""
        return _oezap.OEET_GetInnerMask(self)

    def GetOuterMask(self) -> "float":
        r"""GetOuterMask(OEET self) -> float"""
        return _oezap.OEET_GetOuterMask(self)

    def GetJoin(self) -> "bool":
        r"""GetJoin(OEET self) -> bool"""
        return _oezap.OEET_GetJoin(self)

    def GetGridSpacing(self) -> "float":
        r"""GetGridSpacing(OEET self) -> float"""
        return _oezap.OEET_GetGridSpacing(self)

    def GetGridBuffer(self) -> "float":
        r"""GetGridBuffer(OEET self) -> float"""
        return _oezap.OEET_GetGridBuffer(self)

# Register OEET in _oezap:
_oezap.OEET_swigregister(OEET)


def OEMakeETGrid(grid: "OESystem::OEScalarGrid &", mol: "OEMolBase", et: "OEET") -> "bool":
    r"""OEMakeETGrid(OESystem::OEScalarGrid & grid, OEMolBase mol, OEET et) -> bool"""
    return _oezap.OEMakeETGrid(grid, mol, et)
OE_OEZAP_VERSION = _oezap.OE_OEZAP_VERSION


def OEZapGetRelease() -> "char const *":
    r"""OEZapGetRelease() -> char const *"""
    return _oezap.OEZapGetRelease()

def OEZapGetVersion() -> "unsigned int":
    r"""OEZapGetVersion() -> unsigned int"""
    return _oezap.OEZapGetVersion()

def OEZapGetArch() -> "char const *":
    r"""OEZapGetArch() -> char const *"""
    return _oezap.OEZapGetArch()

def OEZapGetPlatform() -> "char const *":
    r"""OEZapGetPlatform() -> char const *"""
    return _oezap.OEZapGetPlatform()

def OEZapIsLicensed(feature: "char const *"=None, expdate: "unsigned int *"=None) -> "bool":
    r"""OEZapIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool"""
    return _oezap.OEZapIsLicensed(feature, expdate)

def OEZapGetLicensee(*args) -> "std::string":
    r"""
    OEZapGetLicensee(std::string & licensee) -> bool
    OEZapGetLicensee() -> std::string
    """
    return _oezap.OEZapGetLicensee(*args)

def OEZapGetSite(*args) -> "std::string":
    r"""
    OEZapGetSite(std::string & site) -> bool
    OEZapGetSite() -> std::string
    """
    return _oezap.OEZapGetSite(*args)





#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Extract compound(s) from a file based on molecule title
#############################################################################
import sys

try:
    set()
except NameError:
    from sets import Set as set
from openeye import oechem


def MolExtract(ifs, ofs, nameset):
    for mol in ifs.GetOEMols():
        title = mol.GetTitle()
        if title in nameset:
            oechem.OEWriteMolecule(ofs, mol)


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)
    haslist = itf.HasString("-list")
    hastitle = itf.HasString("-title")
    if not (haslist ^ hastitle):
        oechem.OEThrow.Usage("Must give either -list or -title")

    ifs = oechem.oemolistream()
    if not ifs.open(itf.GetString("-i")):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % itf.GetString("-i"))

    ofs = oechem.oemolostream()
    if not ofs.open(itf.GetString("-o")):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-o"))

    # collect names
    nameset = set()
    if itf.HasString("-list"):
        try:
            lfs = open(itf.GetString("-list"))
        except IOError:
            oechem.OEThrow.Fatal("Unable to open %s for reading" % itf.GetString("-list"))
        for name in lfs.readlines():
            name = name.strip()
            nameset.add(name)
    elif itf.HasString("-title"):
        nameset.add(itf.GetString("-title"))

    if len(nameset) == 0:
        oechem.OEThrow.Fatal("No titles requested")

    MolExtract(ifs, ofs, nameset)


InterfaceData = """\
!BRIEF -title title | -list <moltitles.file> [-i] <input> [-o] <output>
!PARAMETER -i
  !ALIAS -in
  !TYPE string
  !REQUIRED true
  !BRIEF Input file name
  !KEYLESS 1
!END
!PARAMETER -o
  !ALIAS -out
  !TYPE string
  !REQUIRED true
  !BRIEF Output file name
  !KEYLESS 2
!END
!PARAMETER -title
  !ALIAS -t
  !TYPE string
  !BRIEF Single mol title to extract
!END
!PARAMETER -list
  !ALIAS -l
  !TYPE string
  !BRIEF List file of mol titles to extract
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################


def DrawHelloWorld(image, font):

    w = image.GetWidth()
    h = image.GetHeight()
    image.Clear(oechem.OEWhite)

    pen = oedepict.OEPen()
    image.DrawRectangle(oedepict.OE2DPoint(1.0, 1.0), oedepict.OE2DPoint(w - 1.0, h - 1.0), pen)

    image.DrawText(oedepict.OE2DPoint(w / 2.0, h / 2.0), "Hello World!", font)


def DrawHelloWorlds(font, basefilename):

    image = oedepict.OEImage(200, 60)
    DrawHelloWorld(image, font)

    oedepict.OEWriteImage(basefilename + ".png", image)
    oedepict.OEWriteImage(basefilename + ".pdf", image)


font = oedepict.OEFont()
DrawHelloWorlds(font, "OEFont_Default")

# @ <SNIPPET-OEFONT-SET-FAMILY>
font = oedepict.OEFont()
font.SetFamily(oedepict.OEFontFamily_Times)
# @ </SNIPPET-OEFONT-SET-FAMILY>
DrawHelloWorlds(font, "OEFont_SetFamily")

# @ <SNIPPET-OEFONT-SET-STYLE>
font = oedepict.OEFont()
font.SetStyle(oedepict.OEFontStyle_Bold | oedepict.OEFontStyle_Italic)
# @ </SNIPPET-OEFONT-SET-STYLE>
DrawHelloWorlds(font, "OEFont_SetStyle")

# @ <SNIPPET-OEFONT-SET-SIZE>
font = oedepict.OEFont()
font.SetSize(30)
# @ </SNIPPET-OEFONT-SET-SIZE>
DrawHelloWorlds(font, "OEFont_SetSize")

# @ <SNIPPET-OEFONT-SET-ALIGNMENT>
font = oedepict.OEFont()
font.SetAlignment(oedepict.OEAlignment_Right)
# @ </SNIPPET-OEFONT-SET-ALIGNMENT>
DrawHelloWorlds(font, "OEFont_SetAlignment")

# @ <SNIPPET-OEFONT-SET-COLOR>
font = oedepict.OEFont()
font.SetColor(oechem.OERed)
# @ </SNIPPET-OEFONT-SET-COLOR>
DrawHelloWorlds(font, "OEFont_SetColor")

# @ <SNIPPET-OEFONT-SET-ROTATION-ANGLE>
font = oedepict.OEFont()
font.SetRotationAngle(180.0)
# @ </SNIPPET-OEFONT-SET-ROTATION-ANGLE>
DrawHelloWorlds(font, "OEFont_SetRotationAngle")



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# This is a multi-threaded version of the example that reads in a
# reference molecule and a few fit molecules, performs overlay optimization,
# and shows the single best result.
# With the default options, OEOverlay optimizes both shape and color.

import sys
from openeye import oechem
from openeye import oeshape
from threading import Thread


class MultiCoreOverlay(Thread):
    def __init__(self, refmol, ifs):
        Thread.__init__(self)
        self._prep = oeshape.OEOverlapPrep()
        self._prep.Prep(refmol)
        self._overlay = oeshape.OEMultiRefOverlay()
        self._overlay.SetupRef(refmol)
        self._ifs = ifs

    def run(self):
        for fitmol in self._ifs.GetOEMols():
            self._prep.Prep(fitmol)
            score = oeshape.OEBestOverlayScore()
            self._overlay.BestOverlay(score, fitmol, oeshape.OEHighestTanimoto())
            print("Fit Title: %-4s FitConfIdx: %-4d RefConfIdx: %-4d tanimoto combo: %.2f"
                  % (fitmol.GetTitle(), score.GetFitConfIdx(),
                     score.GetRefConfIdx(), score.GetTanimotoCombo()))


def main(argv=[__name__]):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <reffile> <fitfile>" % argv[0])

    reffs = oechem.oemolistream(argv[1])
    refmol = oechem.OEMol()
    oechem.OEReadMolecule(reffs, refmol)
    print("Ref. Title:", refmol.GetTitle(), "Num Confs:", refmol.NumConfs())

    fitfs = oechem.oemolithread(sys.argv[2])

    thrds = []
    for i in range(oechem.OEGetNumProcessors()):
        thrd = MultiCoreOverlay(refmol, fitfs)
        thrd.start()
        thrds.append(thrd)

    for thrd in thrds:
        thrd.join()

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem

ifs = oechem.oemolistream()
ifs.open(sys.argv[1])
ifs.SetFormat(oechem.OEFormat_PDB)

# @ <SNIPPET-OESETCRYSTALSYMMETRY>
for pdb in ifs.GetOEGraphMols():
    p = oechem.OECrystalSymmetryParams(124.978, 124.978, 69.000, 90.0, 90.0, 120.0, 154, 4)
    if oechem.OESetCrystalSymmetry(pdb, p):
        print("a= %f b= %f c= %f" % (p.GetA(), p.GetB(), p.GetC()), end=" ")
        print("alpha= %f beta= %f gamma= %f" % (p.GetAlpha(), p.GetBeta(), p.GetGamma()), end=" ")
        print("spacegroup= %d z-value= %d" % (p.GetSpaceGroup(), p.GetZValue()))
# @ </SNIPPET-OESETCRYSTALSYMMETRY>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeshape
from openeye import oegrid


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    NPolyMax = itf.GetInt("-NPolyMax")
    gridspacing = itf.GetFloat("-gridspacing")

    ifname = itf.GetString("-inputfile")
    ofname = itf.GetString("-outputgrid")\

    ifs = oechem.oemolistream()
    if (not ifs.open(ifname)):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % ifname)

    if (not ofname.endswith(".grd")):
        oechem.OEThrow.Fatal("Output grid file extension hast to be '.grd' ")

    mol = oechem.OEMol()

    if (not oechem.OEReadMolecule(ifs, mol)):
        oechem.OEThrow.Fatal("Unable to read molecule in %s" % ifname)

    prep = oeshape.OEOverlapPrep()
    prep.SetAssignColor(False)
    prep.Prep(mol)
    transfm = oechem.OETrans()
    oeshape.OEOrientByMomentsOfInertia(mol, transfm)

    hermiteoptions = oeshape.OEHermiteOptions()
    hermiteoptions.SetNPolyMax(NPolyMax)
    hermiteoptions.SetUseOptimalLambdas(True)

    hermite = oeshape.OEHermite(hermiteoptions)

    if (not hermite.Setup(mol)):
        oechem.OEThrow.Fatal("Was not able to Setup the molecule for the OEHermite class.")

    hopts = hermite.GetOptions()
    print("Best lambdas found X=" + str(hopts.GetLambdaX()) + "  Y="
          + str(hopts.GetLambdaY()) + "  Z=" + str(hopts.GetLambdaZ()))

    print("Hermite self-overlap=", hermite.GetSelfOverlap())

    basis_size = int((NPolyMax+1)*(NPolyMax+2)*(NPolyMax+3)/6)
    coeffs = oechem.OEDoubleVector(basis_size)
    hermite.GetCoefficients(coeffs)
    NPolyMaxstring = str(NPolyMax)
    print("Hermite coefficients f_{l,m,n} in the following order l = 0..."
          + NPolyMaxstring + ", m = 0..." + NPolyMaxstring+"-l, n = " + NPolyMaxstring + "-l-m :")

    for x in coeffs:
        print(str(x) + " "),

    grid = oegrid.OEScalarGrid()

    hermite.CreateGrid(grid, gridspacing, transfm)

    if (not oegrid.OEWriteGrid(ofname, grid)):
        oechem.OEThrow.Fatal("Unable to write grid file")

    return 0


#############################################################################
InterfaceData = '''
!BRIEF [-inputfile] <InputFileName> [-outputgrid] <OutputGridFileName> [-NPolyMax] <NPolyMax> \
[-numgridpoints] <numgridpoints> [-gridspacing] <gridspacing>

!CATEGORY "input/output options :" 1

  !PARAMETER -inputfile 1
    !ALIAS -in
    !TYPE string
    !REQUIRED true
    !BRIEF Filename of the input molecule
    !KEYLESS 1
  !END

  !PARAMETER -outputgrid 2
  !ALIAS -out
    !TYPE string
    !REQUIRED true
    !BRIEF Filename of the output Hermite grid (needs to have .grd file extension)
    !KEYLESS 2
  !END

!END

!CATEGORY "Hermite options :" 2

  !PARAMETER -NPolyMax 3
    !ALIAS -NP
    !TYPE int
    !REQUIRED false
    !DEFAULT 5
    !LEGAL_RANGE 0 30
    !BRIEF Resolution parameter of Hermite Prep
    !KEYLESS 3
  !END


  !PARAMETER -gridspacing 4
    !ALIAS -gs
    !TYPE float
    !REQUIRED false
    !DEFAULT 1.0
    !LEGAL_RANGE 0.01 10.0
    !BRIEF Grid spacing of the output Hermite grid
    !KEYLESS 4
  !END

!END
'''

#############################################################################
if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################################################
# This program demonstrates how to find pockets and some of its properties from a protein or DesignUnit file.
#############################################################################################################
import sys
from openeye import oechem
from openeye import oespruce


def readProteinMol(ifilename):
    if oechem.OEGetFileExtension(ifilename) == 'oedu':
        du = oechem.OEDesignUnit()
        if not oechem.OEReadDesignUnit(ifilename, du):
            oechem.OEThrow.Fatal("Unable to open %s for reading OEDesignUnit" % ifilename)
        return du
    else:
        ifs = oechem.oemolistream()
        if not ifs.open(ifilename):
            oechem.OEThrow.Fatal("Unable to open %s for reading" % ifilename)
        mol = oechem.OEGraphMol()
        oechem.OEReadMolecule(ifs, mol)
        return mol


def main(argv=None):
    if argv is None:
        argv = [__name__]
    if len(sys.argv) != 2:
        oechem.OEThrow.Usage("%s <protein or DesignUnit input file>" % argv[0])

    mol = readProteinMol(sys.argv[1])

    pockets = oespruce.OEFindPockets(mol)
    print("pockets count: %s" % len(list(pockets)))
    pockets.ToFirst()
    pocket_cntr = 0
    for pocket in pockets:
        pocket_cntr += 1
        pocket_residues = pocket.GetResidues()
        print("pocket_%s Residues count: " % pocket_cntr, len(list(pocket_residues)))
        pocket_residues.ToFirst()
        print("pocket_%s Residues: " % pocket_cntr)
        for res in pocket_residues:
            print(res)
        print("pocket_%s Surface Area: " % pocket_cntr,  pocket.GetSurfaceArea())


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "C\\C=C\\C=C/C=CC")

for bond in mol.GetBonds():
    if bond.HasStereoSpecified(oechem.OEBondStereo_CisTrans):
        for atomB in bond.GetBgn().GetAtoms():
            if atomB == bond.GetEnd():
                continue
            for atomE in bond.GetEnd().GetAtoms():
                if atomE == bond.GetBgn():
                    continue
                v = []
                v.append(atomB)
                v.append(atomE)
                stereo = bond.GetStereo(v, oechem.OEBondStereo_CisTrans)
                print("Atoms:", atomB.GetIdx(), "and", atomE.GetIdx(), "are", end=" ")

                if stereo == oechem.OEBondStereo_Cis:
                    print("cis")
                elif stereo == oechem.OEBondStereo_Trans:
                    print("trans")
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oedocking


def main(argv=[__name__]):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <input receptor> <output receptor>" % argv[0])

    # @ <SNIPPET-RECEPTOR-IO-1>
    receptor = oechem.OEGraphMol()
    inputReceptorFilename = argv[1]
    oedocking.OEReadReceptorFile(receptor, inputReceptorFilename)
    # @ </SNIPPET-RECEPTOR-IO-1>

    # @ <SNIPPET-RECEPTOR-IO-2>
    outputReceptorFilename = argv[2]
    oedocking.OEWriteReceptorFile(receptor, outputReceptorFilename)
    # @ </SNIPPET-RECEPTOR-IO-2>

    # @<SNIPPET-RECEPTOR-IO-3>
    bytes = oedocking.OEWriteReceptorToBytes(".oeb", receptor)
    receptorIO = oechem.OEGraphMol()
    status = oedocking.OEReadReceptorFromBytes(receptorIO, ".oeb", bytes)
    # @</SNIPPET-RECEPTOR-IO-3>
    print("SNIPPET-RECEPTOR-IO-3: .oeb      status={} nbytes={}".format(status, len(bytes)))

    # @<SNIPPET-RECEPTOR-IO-4>
    bytes = oedocking.OEWriteReceptorToBytes(".oeb.gz", receptor)
    receptorIO = oechem.OEGraphMol()
    status = oedocking.OEReadReceptorFromBytes(receptorIO, ".oeb.gz", bytes)
    # @</SNIPPET-RECEPTOR-IO-4>
    print("SNIPPET-RECEPTOR-IO-4: .oeb.gz   status={} nbytes={}".format(status, len(bytes)))

    # @<SNIPPET-RECEPTOR-IO-5>
    bytes = oedocking.OEWriteReceptorToBytes(".json", receptor)
    receptorIO = oechem.OEGraphMol()
    status = oedocking.OEReadReceptorFromBytes(receptorIO, ".json", bytes)
    # @</SNIPPET-RECEPTOR-IO-5>
    print("SNIPPET-RECEPTOR-IO-5: .json     status={} nbytes={}".format(status, len(bytes)))

    # @<SNIPPET-RECEPTOR-IO-6>
    bytes = oedocking.OEWriteReceptorToBytes(".json.gz", receptor)
    receptorIO = oechem.OEGraphMol()
    status = oedocking.OEReadReceptorFromBytes(receptorIO, ".json.gz", bytes)
    # @</SNIPPET-RECEPTOR-IO-6>
    print("SNIPPET-RECEPTOR-IO-6: .json.gz  status={} nbytes={}".format(status, len(bytes)))

    # @<SNIPPET-RECEPTOR-IO-7>
    gzip = False
    bytes = oedocking.OEWriteReceptorToBytes(oechem.OEFormat_OEB,
                                             oechem.OEGetDefaultOFlavor(oechem.OEFormat_OEB),
                                             gzip, receptor)
    receptorIO = oechem.OEGraphMol()
    status = oedocking.OEReadReceptorFromBytes(receptorIO, oechem.OEFormat_OEB,
                                               oechem.OEGetDefaultIFlavor(oechem.OEFormat_OEB),
                                               gzip, bytes)
    # @</SNIPPET-RECEPTOR-IO-7>
    print("SNIPPET-RECEPTOR-IO-7: .oeb      status={} nbytes={}".format(status, len(bytes)))

    # @<SNIPPET-RECEPTOR-IO-8>
    gzip = True
    bytes = oedocking.OEWriteReceptorToBytes(oechem.OEFormat_OEB,
                                             oechem.OEGetDefaultOFlavor(oechem.OEFormat_OEB),
                                             gzip, receptor)
    receptorIO = oechem.OEGraphMol()
    status = oedocking.OEReadReceptorFromBytes(receptorIO, oechem.OEFormat_OEB,
                                               oechem.OEGetDefaultIFlavor(oechem.OEFormat_OEB),
                                               gzip, bytes)
    # @</SNIPPET-RECEPTOR-IO-8>
    print("SNIPPET-RECEPTOR-IO-8: .oeb.gz   status={} nbytes={}".format(status, len(bytes)))

    # @<SNIPPET-RECEPTOR-IO-9>
    gzip = False
    bytes = oedocking.OEWriteReceptorToBytes(oechem.OEFormat_JSON,
                                             oechem.OEGetDefaultOFlavor(oechem.OEFormat_JSON),
                                             gzip, receptor)
    receptorIO = oechem.OEGraphMol()
    status = oedocking.OEReadReceptorFromBytes(receptorIO, oechem.OEFormat_JSON,
                                               oechem.OEGetDefaultIFlavor(oechem.OEFormat_JSON),
                                               gzip, bytes)
    # @</SNIPPET-RECEPTOR-IO-9>
    print("SNIPPET-RECEPTOR-IO-9: .json     status={} nbytes={}".format(status, len(bytes)))

    # @<SNIPPET-RECEPTOR-IO-10>
    gzip = True
    bytes = oedocking.OEWriteReceptorToBytes(oechem.OEFormat_JSON,
                                             oechem.OEGetDefaultOFlavor(oechem.OEFormat_JSON),
                                             gzip, receptor)
    receptorIO = oechem.OEGraphMol()
    status = oedocking.OEReadReceptorFromBytes(receptorIO, oechem.OEFormat_JSON,
                                               oechem.OEGetDefaultIFlavor(oechem.OEFormat_JSON),
                                               gzip, bytes)
    # @</SNIPPET-RECEPTOR-IO-10>
    print("SNIPPET-RECEPTOR-IO-10: .json.gz status={} nbytes={}".format(status, len(bytes)))


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################


def DepictMoleculesWithHighlight(smiles, ss, highlight, basefilename):

    mol = oechem.OEGraphMol()
    oechem.OESmilesToMol(mol, smiles)
    oedepict.OEPrepareDepiction(mol)
    opts = oedepict.OE2DMolDisplayOptions(220, 160, oedepict.OEScale_AutoScale)
    disp = oedepict.OE2DMolDisplay(mol, opts)

    unique = True
    for match in ss.Match(mol, unique):
        oedepict.OEAddHighlighting(disp, highlight, match)

    image = oedepict.OEImage(disp.GetWidth(), disp.GetHeight())
    oedepict.OERenderMolecule(image, disp)

    oedepict.OEWriteImage(basefilename + ".png", image)
    oedepict.OEWriteImage(basefilename + ".pdf", image)


smiles = "c1ccc2c(c1)cc(O)cn2"
ss = oechem.OESubSearch("c1ncc(O)cc1")

highlight = oedepict.OEHighlightByLasso(oechem.OEBlack)

# @ <SNIPPET-OEHIGHLIGHTBYLASSO-SETCOLOR>
highlight.SetColor(oechem.OEDarkGreen)
# @ </SNIPPET-OEHIGHLIGHTBYLASSO-SETCOLOR>
DepictMoleculesWithHighlight(smiles, ss, highlight, "OEHighlightByLasso_SetColor")

# @ <SNIPPET-OEHIGHLIGHTBYLASSO-SETPEN>
pen = oedepict.OEPen(oechem.OEGreenTint, oechem.OEDarkGreen,
                     oedepict.OEFill_On, 3.0, oedepict.OEStipple_Dot)
highlight.SetPen(pen)
# @ </SNIPPET-OEHIGHLIGHTBYLASSO-SETPEN>
DepictMoleculesWithHighlight(smiles, ss, highlight, "OEHighlightByLasso_SetPen")

# @ <SNIPPET-OEHIGHLIGHTBYLASSO-SETLASSOSCALE>
highlight = oedepict.OEHighlightByLasso(oechem.OEDarkGreen)
highlight.SetLassoScale(6.0)
# @ </SNIPPET-OEHIGHLIGHTBYLASSO-SETLASSOSCALE>
DepictMoleculesWithHighlight(smiles, ss, highlight, "OEHighlightByLasso_SetLassoScale")

# @ <SNIPPET-OEHIGHLIGHTBYLASSO-SETATOMLABELMONOCHROME>
highlight = oedepict.OEHighlightByLasso(oechem.OEDarkGreen)
highlight.SetAtomLabelMonochrome(False)
# @ </SNIPPET-OEHIGHLIGHTBYLASSO-SETATOMLABELMONOCHROME>
DepictMoleculesWithHighlight(smiles, ss, highlight, "OEHighlightByLasso_SetAtomLabelMonochrome")

# @ <SNIPPET-OEHIGHLIGHTBYLASSO-SETCONSIDERATOMLABELBOUNDINGBOX>
highligh = oedepict.OEHighlightByLasso(oechem.OEDarkGreen)
highlight.SetConsiderAtomLabelBoundingBox(True)
# @ </SNIPPET-OEHIGHLIGHTBYLASSO-SETCONSIDERATOMLABELBOUNDINGBOX>
DepictMoleculesWithHighlight(smiles, ss, highlight,
                             "OEHighlightByLasso_SetConsiderAtomLabelBoundingBox")

# @ <SNIPPET-OEHIGHLIGHTBYLASSO-SETLINEWIDTHSCALE>
highligh = oedepict.OEHighlightByLasso(oechem.OEDarkGreen)
highlight.SetLineWidthScale(3.0)
# @ </SNIPPET-OEHIGHLIGHTBYLASSO-SETLINEWIDTHSCALE>
DepictMoleculesWithHighlight(smiles, ss, highlight, "OEHighlightByLasso_SetLineWidthScale")



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.


from openeye import oechem
from openeye import oeshape


def main(argv=[__name__]):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <reffile> <fitfile>" % argv[0])

    reffs = oechem.oemolistream(argv[1])
    fitfs = oechem.oemolistream(argv[2])

    refmol = oechem.OEGraphMol()
    oechem.OEReadMolecule(reffs, refmol)

    # Prepare reference molecule for calculation
    # With default options this will remove any explicit hydrogens present
    prep = oeshape.OEOverlapPrep()
    prep.Prep(refmol)

    # Get appropriate function to calculate exact shape
    shapeFunc = oeshape.OEExactShapeFunc()
    shapeFunc.SetupRef(refmol)

    res = oeshape.OEOverlapResults()
    for fitmol in fitfs.GetOEGraphMols():
        prep.Prep(fitmol)
        shapeFunc.Overlap(fitmol, res)
        print("title: %s  exact tanimoto = %.2f" %
              (fitmol.GetTitle(), res.GetTanimoto()))


if __name__ == "__main__":
    import sys
    sys.exit(main(sys.argv))



# CONFIDENTIAL. (C) 2022 Cadence Design Systems, Inc. (Cadence)
# All rights reserved.
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO CADENCE
# AND IS SUBJECT TO THE FULL PROTECTION OF COPYRIGHT AND TRADE SECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from Cadence is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact Cadence at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")


def swig_import_helper():
    from os.path import dirname
    import importlib.util
    import importlib.abc

    spec = importlib.machinery.PathFinder().find_spec("_oechem", [dirname(__file__)])

    if spec is None:
        # OpenEye Import Statements
        spec = importlib.machinery.PathFinder().find_spec("libs",[dirname(__file__)])
    libs = importlib.util.module_from_spec(spec)

    import sys
    sys.modules[spec.name] = libs
    spec.loader.exec_module(libs)

    assert not sys.platform.startswith('win')

    _oemolprop = libs.OEGetModule('_oemolprop2621')
    return _oemolprop

_oemolprop = swig_import_helper()
del swig_import_helper

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import weakref

import openeye.oechem as oechem
OEFilterType_Unknown = _oemolprop.OEFilterType_Unknown

OEFilterType_Lead = _oemolprop.OEFilterType_Lead

OEFilterType_Drug = _oemolprop.OEFilterType_Drug

OEFilterType_BlockBuster = _oemolprop.OEFilterType_BlockBuster

OEFilterType_Fragment = _oemolprop.OEFilterType_Fragment

OEFilterType_PAINS = _oemolprop.OEFilterType_PAINS

OEFilterType_Custom = _oemolprop.OEFilterType_Custom

OEFilterType_BlockBusterPAINS = _oemolprop.OEFilterType_BlockBusterPAINS


OEFilterType_Default = OEFilterType_BlockBuster

OEFilterType_Max = _oemolprop.OEFilterType_Max

OEFilterParamSetup_Type = _oemolprop.OEFilterParamSetup_Type

OEFilterParamSetup_All = _oemolprop.OEFilterParamSetup_All

OEFilterParamName_Type = _oemolprop.OEFilterParamName_Type

class OEXLogPResult(object):
    r"""Proxy of C++ OEMolProp::OEXLogPResult class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(OEXLogPResult self, bool valid, float value) -> OEXLogPResult
        __init__(OEXLogPResult self, OEXLogPResult rhs) -> OEXLogPResult
        """
        _oemolprop.OEXLogPResult_swiginit(self, _oemolprop.new_OEXLogPResult(*args))

    def IsValid(self) -> "bool":
        r"""IsValid(OEXLogPResult self) -> bool"""
        return _oemolprop.OEXLogPResult_IsValid(self)

    def GetValue(self) -> "float":
        r"""GetValue(OEXLogPResult self) -> float"""
        return _oemolprop.OEXLogPResult_GetValue(self)
    __swig_destroy__ = _oemolprop.delete_OEXLogPResult

# Register OEXLogPResult in _oemolprop:
_oemolprop.OEXLogPResult_swigregister(OEXLogPResult)


def OEGetXLogPVersion() -> "std::string":
    r"""OEGetXLogPVersion() -> std::string"""
    return _oemolprop.OEGetXLogPVersion()

def OEGetXLogP(mol: "OEMolBase", atomxlogps: "float *"=None) -> "float &":
    r"""OEGetXLogP(OEMolBase mol, float * atomxlogps=None) -> bool"""
    return _oemolprop.OEGetXLogP(mol, atomxlogps)

def OEGetXLogPResult(mol: "OEMolBase", atomxlogps: "float *"=None) -> "OEMolProp::OEXLogPResult":
    r"""OEGetXLogPResult(OEMolBase mol, float * atomxlogps=None) -> OEXLogPResult"""
    return _oemolprop.OEGetXLogPResult(mol, atomxlogps)

def OEGet2dPSAVersion() -> "std::string":
    r"""OEGet2dPSAVersion() -> std::string"""
    return _oemolprop.OEGet2dPSAVersion()

def OEGet2dPSA(mol: "OEMolBase", atomPSA: "float *"=None, SandP: "bool"=False) -> "float &":
    r"""OEGet2dPSA(OEMolBase mol, float * atomPSA=None, bool SandP=False) -> bool"""
    return _oemolprop.OEGet2dPSA(mol, atomPSA, SandP)

def OEGetFractionCsp3(mol: "OEMolBase") -> "float":
    r"""OEGetFractionCsp3(OEMolBase mol) -> float"""
    return _oemolprop.OEGetFractionCsp3(mol)

def OEGetAromaticRingCount(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetAromaticRingCount(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetAromaticRingCount(mol)

def OEGetRotatableBondCount(mol: "OEMolBase", adjust: "bool"=False) -> "unsigned int":
    r"""OEGetRotatableBondCount(OEMolBase mol, bool adjust=False) -> unsigned int"""
    return _oemolprop.OEGetRotatableBondCount(mol, adjust)

def OECheckXLogXType(atom: "OEAtomBase") -> "bool":
    r"""OECheckXLogXType(OEAtomBase atom) -> bool"""
    return _oemolprop.OECheckXLogXType(atom)

def OECheckXLogXTypes(mol: "OEMolBase") -> "bool":
    r"""OECheckXLogXTypes(OEMolBase mol) -> bool"""
    return _oemolprop.OECheckXLogXTypes(mol)
class OEFilter(object):
    r"""Proxy of C++ OEMolProp::OEFilter class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(OEFilter self, unsigned int type=) -> OEFilter
        __init__(OEFilter self, oeistream filterstr) -> OEFilter
        __init__(OEFilter self, OEFilter filter) -> OEFilter
        """
        _oemolprop.OEFilter_swiginit(self, _oemolprop.new_OEFilter(*args))
    __swig_destroy__ = _oemolprop.delete_OEFilter

    def GetImpl(self, *args) -> "OEMolProp::OEFilterImpl const *":
        r"""
        GetImpl(OEFilter self) -> OEMolProp::OEFilterImpl
        GetImpl(OEFilter self) -> OEMolProp::OEFilterImpl const *
        """
        return _oemolprop.OEFilter_GetImpl(self, *args)

    def PrintConfig(self, log: "oeostream") -> "void":
        r"""PrintConfig(OEFilter self, oeostream log)"""
        return _oemolprop.OEFilter_PrintConfig(self, log)

    def GetFilterType(self) -> "unsigned int":
        r"""GetFilterType(OEFilter self) -> unsigned int"""
        return _oemolprop.OEFilter_GetFilterType(self)

    def __call__(self, *args) -> "bool":
        r"""
        __call__(OEFilter self, OEMolBase arg2) -> bool
        __call__(OEFilter self, OEMCMolBase arg2) -> bool
        """
        return _oemolprop.OEFilter___call__(self, *args)

    def GetMessage(self, *args) -> "std::string":
        r"""
        GetMessage(OEFilter self, OEMolBase arg2) -> std::string
        GetMessage(OEFilter self, OEMCMolBase arg2) -> std::string
        """
        return _oemolprop.OEFilter_GetMessage(self, *args)

    def IsValid(self):
      return _oemolprop.OEFilter___nonzero__(self)



    def SetTable(self, table: "oeostream", owned: "bool") -> "void":
        r"""SetTable(OEFilter self, oeostream table, bool owned)"""
        return _oemolprop.OEFilter_SetTable(self, table, owned)

    def GetTable(self) -> "OEPlatform::oeostream *":
        r"""GetTable(OEFilter self) -> oeostream"""
        return _oemolprop.OEFilter_GetTable(self)

    def SetFlagTableFailures(self, b: "bool") -> "void":
        r"""SetFlagTableFailures(OEFilter self, bool b)"""
        return _oemolprop.OEFilter_SetFlagTableFailures(self, b)

    def GetFlagTableFailures(self) -> "bool":
        r"""GetFlagTableFailures(OEFilter self) -> bool"""
        return _oemolprop.OEFilter_GetFlagTableFailures(self)

    def SetCanonOrder(self, b: "bool") -> "void":
        r"""SetCanonOrder(OEFilter self, bool b)"""
        return _oemolprop.OEFilter_SetCanonOrder(self, b)

    def GetCanonOrder(self) -> "bool":
        r"""GetCanonOrder(OEFilter self) -> bool"""
        return _oemolprop.OEFilter_GetCanonOrder(self)

    def SetpKaNormalize(self, b: "bool") -> "void":
        r"""SetpKaNormalize(OEFilter self, bool b)"""
        return _oemolprop.OEFilter_SetpKaNormalize(self, b)

    def GetpKaNormalize(self) -> "bool":
        r"""GetpKaNormalize(OEFilter self) -> bool"""
        return _oemolprop.OEFilter_GetpKaNormalize(self)

    def AddNormalizationRule(self, rxn: "OEUniMolecularRxn") -> "bool":
        r"""AddNormalizationRule(OEFilter self, OEUniMolecularRxn rxn) -> bool"""
        return _oemolprop.OEFilter_AddNormalizationRule(self, rxn)

    def ClearNormalizationRules(self) -> "void":
        r"""ClearNormalizationRules(OEFilter self)"""
        return _oemolprop.OEFilter_ClearNormalizationRules(self)

    def ParseNewRules(self, rulefile: "oeistream") -> "bool":
        r"""ParseNewRules(OEFilter self, oeistream rulefile) -> bool"""
        return _oemolprop.OEFilter_ParseNewRules(self, rulefile)

    def SetTypeCheck(self, b: "bool") -> "void":
        r"""SetTypeCheck(OEFilter self, bool b)"""
        return _oemolprop.OEFilter_SetTypeCheck(self, b)

    def GetTypeCheck(self) -> "bool":
        r"""GetTypeCheck(OEFilter self) -> bool"""
        return _oemolprop.OEFilter_GetTypeCheck(self)

    def SetMMFFTypeCheck(self, b: "bool") -> "void":
        r"""SetMMFFTypeCheck(OEFilter self, bool b)"""
        return _oemolprop.OEFilter_SetMMFFTypeCheck(self, b)

    def GetMMFFTypeCheck(self) -> "bool":
        r"""GetMMFFTypeCheck(OEFilter self) -> bool"""
        return _oemolprop.OEFilter_GetMMFFTypeCheck(self)

    def SetSDTag(self, b: "bool") -> "void":
        r"""SetSDTag(OEFilter self, bool b)"""
        return _oemolprop.OEFilter_SetSDTag(self, b)

    def GetSDTag(self) -> "bool":
        r"""GetSDTag(OEFilter self) -> bool"""
        return _oemolprop.OEFilter_GetSDTag(self)

    def SetErrorLevel(self, level: "unsigned int") -> "void":
        r"""SetErrorLevel(OEFilter self, unsigned int level)"""
        return _oemolprop.OEFilter_SetErrorLevel(self, level)

    def GetErrorLevel(self) -> "unsigned int":
        r"""GetErrorLevel(OEFilter self) -> unsigned int"""
        return _oemolprop.OEFilter_GetErrorLevel(self)

# Register OEFilter in _oemolprop:
_oemolprop.OEFilter_swigregister(OEFilter)

OE_OEMOLPROP_VERSION = _oemolprop.OE_OEMOLPROP_VERSION


def OEMolPropGetRelease() -> "char const *":
    r"""OEMolPropGetRelease() -> char const *"""
    return _oemolprop.OEMolPropGetRelease()

def OEMolPropGetVersion() -> "unsigned int":
    r"""OEMolPropGetVersion() -> unsigned int"""
    return _oemolprop.OEMolPropGetVersion()

def OEMolPropGetArch() -> "char const *":
    r"""OEMolPropGetArch() -> char const *"""
    return _oemolprop.OEMolPropGetArch()

def OEMolPropGetPlatform() -> "char const *":
    r"""OEMolPropGetPlatform() -> char const *"""
    return _oemolprop.OEMolPropGetPlatform()

def OEMolPropIsLicensed(feature: "char const *"=None, expdate: "unsigned int *"=None) -> "bool":
    r"""OEMolPropIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool"""
    return _oemolprop.OEMolPropIsLicensed(feature, expdate)

def OEMolPropGetLicensee(*args) -> "std::string":
    r"""
    OEMolPropGetLicensee(std::string & licensee) -> bool
    OEMolPropGetLicensee() -> std::string
    """
    return _oemolprop.OEMolPropGetLicensee(*args)

def OEMolPropGetSite(*args) -> "std::string":
    r"""
    OEMolPropGetSite(std::string & site) -> bool
    OEMolPropGetSite() -> std::string
    """
    return _oemolprop.OEMolPropGetSite(*args)

def OEConfigureFilterParams(*args) -> "bool":
    r"""OEConfigureFilterParams(OEInterface itf, unsigned int config=) -> bool"""
    return _oemolprop.OEConfigureFilterParams(*args)

def OEGetFilterType(*args) -> "unsigned int":
    r"""OEGetFilterType(OEInterface itf, std::string name=) -> unsigned int"""
    return _oemolprop.OEGetFilterType(*args)

def OEConfigureFilterType(*args) -> "bool":
    r"""OEConfigureFilterType(OEInterface itf, std::string name=, std::string alias="-ftype") -> bool"""
    return _oemolprop.OEConfigureFilterType(*args)

def OEGetHalideFraction(mol: "OEMolBase", isotopic: "bool"=False) -> "double":
    r"""OEGetHalideFraction(OEMolBase mol, bool isotopic=False) -> double"""
    return _oemolprop.OEGetHalideFraction(mol, isotopic)

def OEGetHBondDonorCount(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetHBondDonorCount(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetHBondDonorCount(mol)

def OEGetHBondAcceptorCount(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetHBondAcceptorCount(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetHBondAcceptorCount(mol)

def OEGetLipinskiDonorCount(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetLipinskiDonorCount(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetLipinskiDonorCount(mol)

def OEGetLipinskiAcceptorCount(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetLipinskiAcceptorCount(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetLipinskiAcceptorCount(mol)

def OEWritePropertyDataToCSV(*args) -> "bool":
    r"""
    OEWritePropertyDataToCSV(std::string const & fname, oemolistream ifs, OEFilter filter) -> bool
    OEWritePropertyDataToCSV(oemolostream ofs, oemolistream ifs, OEFilter filter) -> bool
    """
    return _oemolprop.OEWritePropertyDataToCSV(*args)

def OEGetLongestUnbranchedHeavyAtomsChain(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetLongestUnbranchedHeavyAtomsChain(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetLongestUnbranchedHeavyAtomsChain(mol)

def OEGetLongestUnbranchedCarbonsChain(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetLongestUnbranchedCarbonsChain(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetLongestUnbranchedCarbonsChain(mol)

def OEGetAnionicCarbonCount(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetAnionicCarbonCount(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetAnionicCarbonCount(mol)

def OEGetNumUnspecifiedAtomStereos(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetNumUnspecifiedAtomStereos(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetNumUnspecifiedAtomStereos(mol)

def OEGetNumUnspecifiedBondStereos(mol: "OEMolBase") -> "unsigned int":
    r"""OEGetNumUnspecifiedBondStereos(OEMolBase mol) -> unsigned int"""
    return _oemolprop.OEGetNumUnspecifiedBondStereos(mol)





#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# analyze binding site energies with szmaptk

import sys
from openeye import oechem
from openeye import oeszmap

InterfaceData = """
!BRIEF SzmapEnergies.py [-p] <molfile> [-l] <molfile>
!PARAMETER -p
  !TYPE string
  !BRIEF Input protein (or other) context mol
  !REQUIRED true
  !KEYLESS 1
!END
!PARAMETER -l
  !TYPE string
  !BRIEF Input ligand coordinates for calculations
  !REQUIRED true
  !KEYLESS 2
!END
!PARAMETER -high_res
  !TYPE bool
  !DEFAULT false
  !BRIEF If true, increase the number of rotations to 360
  !REQUIRED false
!END
"""


def GetSzmapEnergies(lig, prot, highRes):
    """
    run szmap at ligand coordinates in the protein context
    @rtype : None
    @param lig: mol defining coordinates for szmap calcs
    @param prot: context mol for szmap calcs (must have charges and radii)
    @param highRes: if true, use 360 rotations rather than the default of 60
    """

    opt = oeszmap.OESzmapEngineOptions()
    if highRes:
        opt.SetProbe(360)

    sz = oeszmap.OESzmapEngine(prot, opt)
    coord = oechem.OEFloatArray(3)
    rslt = oeszmap.OESzmapResults()

    print("num\tatom\t%s\t%s\t%s\t%s\t%s"
          % (oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_NeutralDiffDeltaG),
             oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_PSolv),
             oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_WSolv),
             oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_VDW),
             oeszmap.OEGetEnsembleName(oeszmap.OEEnsemble_OrderParam)))

    for i, atom in enumerate(lig.GetAtoms()):
        lig.GetCoords(atom, coord)

        if not oeszmap.OEIsClashing(sz, coord):
            oeszmap.OECalcSzmapResults(rslt, sz, coord)

            print("%2d\t%s\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f"
                  % (i, atom.GetName(),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_NeutralDiffDeltaG),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_PSolv),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_WSolv),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_VDW),
                     rslt.GetEnsembleValue(oeszmap.OEEnsemble_OrderParam)))
        else:
            print("%2d\t%s CLASH" % (i, atom.GetName()))


def main(argv=(__name__)):
    """
    the protein should have charges and radii but the ligand need not
    """
    itf = oechem.OEInterface()

    if not oechem.OEConfigure(itf, InterfaceData):
        oechem.OEThrow.Fatal("Problem configuring OEInterface!")

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to parse command line")

    ligFile = itf.GetString("-l")
    ims = oechem.oemolistream()
    if not ims.open(ligFile):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % ligFile)
    lig = oechem.OEGraphMol()
    oechem.OEReadMolecule(ims, lig)

    contextFile = itf.GetString("-p")
    ims = oechem.oemolistream()
    if not ims.open(contextFile):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % contextFile)
    prot = oechem.OEGraphMol()
    oechem.OEReadMolecule(ims, prot)

    highRes = itf.GetBool("-high_res")
    GetSzmapEnergies(lig, prot, highRes)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# This program demonstrates how to apply charges to an OEDesignUnit.
#############################################################################

import sys
from openeye import oechem
from openeye import oequacpac


def main(argv=[__name__]):
    opts = oechem.OESimpleAppOptions("applycharges_du", oechem.OEFileStringType_DU,
                                     oechem.OEFileStringType_DU)
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0

    ifs = oechem.oeifstream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    ofs = oechem.oeofstream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    du = oechem.OEDesignUnit()
    while oechem.OEReadDesignUnit(ifs, du):
        charge_engine = oequacpac.OEDesignUnitCharges()
        if charge_engine.ApplyCharges(du):
            oechem.OEWriteDesignUnit(ofs, du)
        else:
            oechem.OEThrow.Warning("%s: %s" % (du.GetTitle(), "Failed to assign charges"))
    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem

# @ <SNIPPET>
qmol = oechem.OEQMol()
oechem.OEParseSmarts(qmol, "C1CC[O,N]CC1")

# generate screens
qscreen = oechem.OESubSearchScreen()
if not oechem.OEMakeSubSearchQueryScreen(qscreen, qmol, oechem.OESubSearchScreenType_SMARTS):
    print("query SMARTS screen cannot be generated")

tmol = oechem.OEGraphMol()
oechem.OESmilesToMol(tmol, "C1CCOCC1")

tscreen = oechem.OESubSearchScreen()
if not oechem.OEMakeSubSearchTargetScreen(tscreen, tmol, oechem.OESubSearchScreenType_SMARTS):
    print("target SMARTS screen cannot be generated")
# @ </SNIPPET>

if oechem.OEScreen(qscreen, tscreen):
    print("screen match")
else:
    print("no match")



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.


import sys
from openeye import oechem
from openeye import oegrid


def SetupInterface(itf, argv):
    if not oechem.OEConfigure(itf, InterfaceData):
        return False

    if oechem.OECheckHelp(itf, argv):
        return False

    return oechem.OEParseCommandLine(itf, argv)


def main(argv=[__name__]):
    itf = oechem.OEInterface()
    if not SetupInterface(itf, argv):
        return 1

    res = itf.GetFloat("-res")

    regularize = itf.GetBool("-regularize")

    outfile = itf.GetString("-o")
    if not oegrid.OEIsWriteableGrid(oegrid.OEGetGridFileType(oechem.OEGetFileExtension(outfile))):
        oechem.OEThrow.Fatal("Not a writeable grid file: %s" % outfile)

    infile = itf.GetString("-i")

    if oegrid.OEIsReadableGrid(oegrid.OEGetGridFileType(oechem.OEGetFileExtension(infile))):
        if (regularize):
            grid = oegrid.OEScalarGrid()
        else:
            grid = oegrid.OESkewGrid()

        if oegrid.OEReadGrid(infile, grid):
            oegrid.OEWriteGrid(outfile, grid)
        else:
            oechem.OEThrow.Fatal("Problem reading grid file: %s" % infile)
    elif oechem.OEIsReadable(oechem.OEGetFileType(oechem.OEGetFileExtension(infile))):
        ifs = oechem.oemolistream(infile)
        mol = oechem.OEMol()
        if oechem.OEReadMolecule(ifs, mol):
            oechem.OEAssignBondiVdWRadii(mol)
            grid = oegrid.OEScalarGrid()
            oegrid.OEMakeMolecularGaussianGrid(grid, mol, res)
            oegrid.OEWriteGrid(outfile, grid)
        else:
            oechem.OEThrow.Fatal("Problem reading molecule file: %s" % infile)
    else:
        oechem.OEThrow.Fatal("Not a readable grid file: %s", infile)

    oechem.OEThrow.Info("Converted %s into %s" % (infile, outfile))

    return 0


InterfaceData = """
# gridbabel

!PARAMETER -i
  !TYPE string
  !REQUIRED true
  !KEYLESS 1
  !BRIEF input filename
!END

!PARAMETER -o
  !TYPE string
  !REQUIRED true
  !KEYLESS 2
  !BRIEF output filename
!END

!PARAMETER -res
  !TYPE float
  !REQUIRED false
  !DEFAULT 0.5
  !LEGAL_RANGE 0.1 4.0
!END

!PARAMETER -regularize
  !TYPE bool
  !DEFAULT false
  !REQUIRED false
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Generate canonical smiles of various flavors
#############################################################################
import sys
from openeye import oechem

#############################################################################
# To create unique Kekule smiles, must reperceive bond orders from
# scratch to avoid arbitrary non-deterministic variations, e.g.,
# CC1=C(O)C=CC=C1 vs. CC1=CC=CC=C1O
# This is why oechem.OESMILESFlag_Kekule is not sufficient and not used.
#############################################################################


def CanSmi(mol, isomeric, kekule):
    oechem.OEFindRingAtomsAndBonds(mol)
    oechem.OEAssignAromaticFlags(mol, oechem.OEAroModel_OpenEye)
    smiflag = oechem.OESMILESFlag_Canonical
    if isomeric:
        smiflag |= oechem.OESMILESFlag_ISOMERIC

    if kekule:
        for bond in mol.GetBonds(oechem.OEIsAromaticBond()):
            bond.SetIntType(5)
        oechem.OECanonicalOrderAtoms(mol)
        oechem.OECanonicalOrderBonds(mol)
        oechem.OEClearAromaticFlags(mol)
        oechem.OEKekulize(mol)

    smi = oechem.OECreateSmiString(mol, smiflag)
    return smi


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    isomeric = itf.GetBool("-isomeric")
    kekule = itf.GetBool("-kekule")
    from3d = itf.GetBool("-from3d")

    if from3d:
        isomeric = True

    ifs = oechem.oemolistream()
    ifile = itf.GetString("-i")
    if not ifs.open(ifile):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % ifile)

    if itf.HasString("-o"):
        ofile = itf.GetString("-o")
        try:
            ofs = open(ofile, 'w')
        except Exception:
            oechem.OEThrow.Fatal("Unable to open %s for writing" % ofile)
    else:
        ofs = sys.stdout

    mol = oechem.OEGraphMol()
    while oechem.OEReadMolecule(ifs, mol):
        if from3d:
            oechem.OE3DToInternalStereo(mol)
        smi = CanSmi(mol, isomeric, kekule)
        if mol.GetTitle():
            smi += (" %s" % mol.GetTitle())
        ofs.write("%s\n" % smi)


InterfaceData = """\
!BRIEF [options] [-i] <input> [[-o] <output>]
!PARAMETER -i
  !ALIAS -in
  !TYPE string
  !REQUIRED true
  !BRIEF input file name
  !KEYLESS 1
!END
!PARAMETER -o
  !ALIAS -out
  !TYPE string
  !BRIEF output file name
  !KEYLESS 2
!END
!PARAMETER -isomeric
  !TYPE bool
  !DEFAULT false
  !BRIEF generate isomeric smiles
!END
!PARAMETER -from3d
  !TYPE bool
  !DEFAULT false
  !BRIEF perceive stereo from 3D coords
!END
!PARAMETER -kekule
  !TYPE bool
  !DEFAULT false
  !BRIEF generate kekule form
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Rename SDF molecules by specified field
#############################################################################
import sys
from openeye import oechem


def Rename(ifs, ofs, fieldname):
    for mol in ifs.GetOEGraphMols():
        if oechem.OEHasSDData(mol, fieldname):
            mol.SetTitle(oechem.OEGetSDData(mol, fieldname))
        else:
            title = mol.GetTitle()
            oechem.OEThrow.Warning("Renaming of molecule %s failed; no field %s" %
                                   (title, fieldname))
        oechem.OEWriteMolecule(ofs, mol)


def main(argv=[__name__]):
    if len(argv) != 4:
        oechem.OEThrow.Usage("%s <fieldname> <infile> <outfile>" % argv[0])

    fieldname = argv[1]
    ifs = oechem.oemolistream()
    if not ifs.open(argv[2]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[2])
    if not oechem.OEIsSDDataFormat(ifs.GetFormat()):
        oechem.OEThrow.Fatal("Only works for input file formats that support SD data (sdf,oeb,csv)")

    ofs = oechem.oemolostream()
    if not ofs.open(argv[3]):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % argv[3])

    Rename(ifs, ofs, fieldname)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



# CONFIDENTIAL. (C) 2022 Cadence Design Systems, Inc. (Cadence)
# All rights reserved.
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO CADENCE
# AND IS SUBJECT TO THE FULL PROTECTION OF COPYRIGHT AND TRADE SECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from Cadence is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact Cadence at eyesopen.com/legal if you have any questions
# about this warning.
"""
 Test suite for FastROCS TK examples
"""

import pytest
from tempfile import NamedTemporaryFile
from . import OETestCase, check_license, check_fastrocs

# Order of skipif is not clearly defined so the check_license() may
# fail first and give a misleading reason because it tries the import also

@pytest.mark.skipif(check_fastrocs() == 0 and not check_license('fastrocs'),
                    reason='FastROCS license not found')
@pytest.mark.skipif(check_fastrocs() == 35,
                    reason='Insufficient NVIDIA Driver! Please update.')
@pytest.mark.skipif(check_fastrocs() == 1,
                    reason='No device found!')
@pytest.mark.skipif(check_fastrocs() == 3,
                    reason='CUDA driver and runtime could not be initialized!')
@pytest.mark.skipif(check_fastrocs() == 38,
                    reason='No CUDA-capable devices were detected!')
@pytest.mark.skipif(check_fastrocs() == 100,
                    reason='No CUDA-capable devices were detected!')
@pytest.mark.skipif(check_fastrocs() == 800,
                    reason='Attempted operation is not permitted!')
@pytest.mark.skipif(check_fastrocs() == -1,
                    reason='FastROCS is not supported on this platform!')
@pytest.mark.skipif(check_fastrocs() == 999,
                    reason='FastROCS is not available! Unknown error.')

class TestFastROCS(OETestCase):
    def test_simple_fastrocs_search(self):
        outfile = NamedTemporaryFile(prefix="fastrocs_", suffix='.oeb', delete=True)
        script = self.run_example(
            '{0}/fastrocs/SimpleFastROCSSearch.py'.format(self.EXAMPLES_DIR),
            '{0}/drugs.sdf'.format(self.DATA_DIR),
            '{0}/4std_lig.oeb.gz'.format(self.DATA_DIR),
            outfile.name,
            expect_stderr=True)
        if "No supported GPU available!" in script.stderr:
            pytest.skip('No supported GPU available!')
        self.assertFalse(script.returncode)



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

imagewidth, imageheight = 350, 250
image = oedepict.OEImage(imagewidth, imageheight)

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1cccnc1O")
oedepict.OEPrepareDepiction(mol)
oedepict.OERenderMolecule(image, mol)

# @ <SNIPPET-LEGEND-LAYOUT>
opts = oedepict.OELegendLayoutOptions(oedepict.OELegendLayoutStyle_VerticalTopRight,
                                      oedepict.OELegendColorStyle_LightGreen,
                                      oedepict.OELegendInteractiveStyle_Toggle)
opts.SetButtonWidthScale(1.5)
opts.SetButtonHeightScale(1.5)
legend = oedepict.OELegendLayout(image, "Legend", opts)

legend_area = legend.GetLegendArea()
oedepict.OEAddWatermark(legend_area, "This is the legend area")
oedepict.OEAddInteractiveIcon(image, oedepict.OEIconLocation_BottomRight, 0.75)
oedepict.OEDrawLegendLayout(legend)

oedepict.OEWriteImage("LegendLayout.svg", image)
# @ </SNIPPET-LEGEND-LAYOUT>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem

ifs = oechem.oemolistream()
ifs.open(sys.argv[1])
mol = oechem.OEGraphMol()
oechem.OEReadMolecule(ifs, mol)

# @ <SNIPPET-OEAtomMatchResidue>
resAla = oechem.OEAtomMatchResidueID()
resAla.SetName("ALA")
predAla = oechem.OEAtomMatchResidue(resAla)
print("Number of atoms matching residue name ALA = ", oechem.OECount(mol, predAla))

resChainA = oechem.OEAtomMatchResidueID()
resChainA.SetChainID("A")
predChainA = oechem.OEAtomMatchResidue(resChainA)
print("Number of atoms matching chain A = ", oechem.OECount(mol, predChainA))

resHis = oechem.OEAtomMatchResidueID()
resHis.SetName("HIS")
resHis.SetChainID("A")
resHis.SetResidueNumber("88")
predHis = oechem.OEAtomMatchResidue(resHis)
print("Number of atoms matching residue (HIS A 88) = ", oechem.OECount(mol, predHis))

# alternative way to initialize as regex
predHis2 = oechem.OEAtomMatchResidue("HIS:88:.*:A:.*:.*")
print("Number of atoms matching residue (HIS A 88) = ", oechem.OECount(mol, predHis2))

backbonepred = oechem.OEIsBackboneAtom()
print("Backbone atoms of residue (HIS A 88): ")
for atom in mol.GetAtoms(oechem.OEAndAtom(predHis, backbonepred)):
    print(atom, oechem.OEAtomGetResidue(atom))
# @ </SNIPPET-OEAtomMatchResidue>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oegraphsim
import sys

if len(sys.argv) != 3:
    oechem.OEThrow.Usage("%s <queryfile> <targetfile>" % sys.argv[0])

ifs = oechem.oemolistream()
if not ifs.open(sys.argv[1]):
    oechem.OEThrow.Fatal("Unable to open %s for reading" % sys.argv[1])

qmol = oechem.OEGraphMol()
oechem.OEReadMolecule(ifs, qmol)
qfp = oegraphsim.OEFingerPrint()
oegraphsim.OEMakeFP(qfp, qmol, oegraphsim.OEFPType_Path)

if not ifs.open(sys.argv[2]):
    oechem.OEThrow.Fatal("Unable to open %s for reading" % sys.argv[2])


fpdb = oegraphsim.OEFPDatabase(qfp.GetFPTypeBase())
for tmol in ifs.GetOEGraphMols():
    fpdb.AddFP(tmol)

print("Tanimoto scores:")
# @ <SNIPPET-GET-SCORES-1>
descending = True
fpdb.SetSimFunc(oegraphsim.OESimMeasure_Tanimoto, descending)
fpdb.SetCutoff(0.1)
for score in fpdb.GetScores(qfp, 0, 100):
    print("%.3f" % score.GetScore())
# @ </SNIPPET-GET-SCORES-1>

fpdb.ClearCutoff()
print("Tversky scores:")
# @ <SNIPPET-GET-SCORES-2>
fpdb.SetSimFunc(oegraphsim.OETverskySim(0.9))
for score in fpdb.GetScores(qfp):
    print("%.3f" % score.GetScore())
# @ </SNIPPET-GET-SCORES-2>

print("Dice scores:")
# @ <SNIPPET-GET-SCORES-3>
descending = True
fpdb.SetSimFunc(oegraphsim.OESimMeasure_Dice, not descending)
fpdb.SetCutoff(0.5)
for score in fpdb.GetScores(qfp, 100):
    print("%.3f" % score.GetScore())
# @ </SNIPPET-GET-SCORES-3>

print("Cosine scores with option:")
# @ <SNIPPET-GET-SCORES-OPTIONS>
opts = oegraphsim.OEFPDatabaseOptions()
opts.SetCutoff(0.3)
opts.SetSimFunc(oegraphsim.OESimMeasure_Cosine)
for score in fpdb.GetScores(qfp, opts):
    print("%.3f" % score.GetScore())
# @ </SNIPPET-GET-SCORES-OPTIONS>

print("Tanimoto sorted scores:")
fpdb.ClearCutoff()  # default
descending = True
fpdb.SetSimFunc(oegraphsim.OESimMeasure_Tanimoto, descending)  # default
# @ <SNIPPET-GET-SORTED-SCORES-1>
for score in fpdb.GetSortedScores(qfp, 10):
    print("%.3f" % score.GetScore())
# @ </SNIPPET-GET-SORTED-SCORES-1>

print("Dice sorted scores:")
# @ <SNIPPET-GET-SORTED-SCORES-2>
descending = True
fpdb.SetSimFunc(oegraphsim.OESimMeasure_Dice, descending)
fpdb.SetCutoff(0.5)
for score in fpdb.GetSortedScores(qfp, 0, 0, 100):
    print("%.3f" % score.GetScore())
# @ </SNIPPET-GET-SORTED-SCORES-2>

print("Manhattan sorted scores:")
# @ <SNIPPET-GET-SORTED-SCORES-3>
descending = True
fpdb.SetSimFunc(oegraphsim.OESimMeasure_Manhattan, not descending)
fpdb.SetCutoff(0.3)
for score in fpdb.GetSortedScores(qfp, 5, 100):
    print("%.3f" % score.GetScore())
# @ </SNIPPET-GET-SORTED-SCORES-3>

print("Tversky sorted scores with options:")
# @ <SNIPPET-GET-SORTED-SCORES-OPTIONS>
opts = oegraphsim.OEFPDatabaseOptions()
opts.SetDescendingOrder(True)
opts.SetCutoff(0.3)
opts.SetSimFunc(oegraphsim.OESimMeasure_Tversky)
opts.SetTverskyCoeffs(0.9, 0.1)
opts.SetLimit(10)
for score in fpdb.GetSortedScores(qfp, opts):
    print("%.3f" % score.GetScore())
# @ </SNIPPET-GET-SORTED-SCORES-OPTIONS>



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Aligns molecules to a smarts pattern
#############################################################################

import sys
from openeye import oechem
from openeye import oedepict


def main(argv=[__name__]):

    itf = oechem.OEInterface(InterfaceData)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    iname = itf.GetString("-in")
    oname = itf.GetString("-out")
    smarts = itf.GetString("-smarts")

    qmol = oechem.OEQMol()
    if not oechem.OEParseSmarts(qmol, smarts):
        oechem.OEThrow.Fatal("Invalid SMARTS: %s" % smarts)
    oechem.OEGenerate2DCoordinates(qmol)

    ss = oechem.OESubSearch(qmol)
    if not ss.IsValid():
        oechem.OEThrow.Fatal("Unable to initialize substructure search!")

    ifs = oechem.oemolistream()
    if not ifs.open(iname):
        oechem.OEThrow.Fatal("Cannot open input molecule file!")

    ofs = oechem.oemolostream()
    if not ofs.open(oname):
        oechem.OEThrow.Fatal("Cannot open output file!")
    if not oechem.OEIs2DFormat(ofs.GetFormat()):
        oechem.OEThrow.Fatal("Invalid output format for 2D coordinates")

    for mol in ifs.GetOEGraphMols():
        oechem.OEPrepareSearch(mol, ss)

        alignres = oedepict.OEPrepareAlignedDepiction(mol, ss)
        if not alignres.IsValid():
            oechem.OEThrow.Warning("Substructure is not found in input molecule!")
            oedepict.OEPrepareDepiction(mol)

        oechem.OEWriteMolecule(ofs, mol)

    return 0


#############################################################################
# INTERFACE
#############################################################################

InterfaceData = '''
!BRIEF [-in] <input> [-smarts] <smarts> [-out] <output>

!CATEGORY "input/output options :"

    !PARAMETER -in
      !ALIAS -i
      !TYPE string
      !REQUIRED true
      !KEYLESS 1
      !VISIBILITY simple
      !BRIEF Filename of input molecules
    !END

    !PARAMETER -smarts
      !ALIAS -s
      !TYPE string
      !REQUIRED true
      !KEYLESS 2
      !VISIBILITY simple
      !BRIEF SMARTS for alignment match
    !END

    !PARAMETER -out
      !ALIAS -o
      !TYPE string
      !REQUIRED true
      !KEYLESS 3
      !VISIBILITY simple
      !BRIEF Output filename
    !END

!END
'''

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#######################################################################
# Extracting rings/ring systems from input molecules
#######################################################################
import sys
from openeye import oechem


def RingSubSet(ifs, ofs, exo):
    for mol in ifs.GetOEGraphMols():
        submol = oechem.OEGraphMol()
        adjustHcount = True
        if exo:
            isinring = oechem.OEAtomIsInRing()
            isexo = oechem.OEIsNonRingAtomDoubleBondedToRing()
            includeexo = oechem.OEOrAtom(isinring, isexo)
            oechem.OESubsetMol(submol, mol, includeexo, adjustHcount)
        else:
            oechem.OESubsetMol(submol, mol, oechem.OEAtomIsInRing(), adjustHcount)
        submol.SetTitle(mol.GetTitle() + "_rings")
        if submol.NumAtoms() != 0:
            oechem.OEWriteMolecule(ofs, submol)


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    exo_dbl_bonds = itf.GetBool("-exo")

    ifs = oechem.oemolistream()
    if not ifs.open(itf.GetString("-i")):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % itf.GetString("-i"))

    ofs = oechem.oemolostream(".ism")
    if itf.HasString("-o"):
        if not ofs.open(itf.GetString("-o")):
            oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-o"))
    RingSubSet(ifs, ofs, exo_dbl_bonds)


InterfaceData = """
!BRIEF [-exo] [-i] <infile> [[-o] <outfile>]
!PARAMETER -i
  !ALIAS -in
  !TYPE string
  !REQUIRED true
  !BRIEF input file name
  !KEYLESS 1
!END
!PARAMETER -o
  !ALIAS -out
  !TYPE string
  !REQUIRED false
  !BRIEF output file name
  !KEYLESS 2
!END
!PARAMETER -exo
  !TYPE bool
  !DEFAULT true
  !BRIEF Include non-ring atoms double bonded to a ring
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oeff
from openeye import oeomega

mol = oechem.OEMol()
oechem.OESmilesToMol(mol, "C1CCCCC1N(=O)CCS")

# @ <SNIPPET-GPUOmega-sparse>
omegaOpts = oeomega.OEOmegaOptions()
omegaOpts.GetTorDriveOptions().SetUseGPU(False)
omega = oeomega.OEOmega(omegaOpts)
omega(mol)
# @ </SNIPPET-GPUOmega-sparse>

# @ <SNIPPET-GPUOmega-dense>
omegaOpts = oeomega.OEOmegaOptions(oeomega.OEOmegaSampling_Dense)
if oeomega.OEOmegaIsGPUReady():
    omegaOpts.GetTorDriveOptions().SetForceField(oeff.OEMMFFSheffieldFFType_MMFF94Smod_NOESTAT)
    omegaOpts.GetMolBuilderOptions().SetSampleHydrogens(False)
omega = oeomega.OEOmega(omegaOpts)
omega(mol)
# @ </SNIPPET-GPUOmega-dense>



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oespicoli


def AtomInHydrophobicResidue(atom):
    residues = set([oechem.OEResidueIndex_ALA,
                    oechem.OEResidueIndex_ILE,
                    oechem.OEResidueIndex_LEU,
                    oechem.OEResidueIndex_MET,
                    oechem.OEResidueIndex_PHE,
                    oechem.OEResidueIndex_PRO,
                    oechem.OEResidueIndex_TRP,
                    oechem.OEResidueIndex_VAL])

    if oechem.OEGetResidueIndex(atom) in residues:
        return True
    else:
        return False


def main(args):
    if len(args) != 3:
        oechem.OEThrow.Usage("%s <protein> <surface>" % args[0])

    ifs = oechem.oemolistream()
    if not ifs.open(args[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % args[1])

    mol = oechem.OEGraphMol()
    oechem.OEReadMolecule(ifs, mol)
    oechem.OEPerceiveResidues(mol)
    oechem.OEAssignBondiVdWRadii(mol)

    # Generate the molecular surface
    surf = oespicoli.OESurface()
    oespicoli.OEMakeMolecularSurface(surf, mol, 0.5)

    # Mark all the vertices associated with hydrophobic atoms
    for i in range(surf.GetNumVertices()):
        atom = mol.GetAtom(oechem.OEHasAtomIdx(surf.GetAtomsElement(i)))
        if (AtomInHydrophobicResidue(atom)):
            surf.SetVertexCliqueElement(i, 1)

    # Crop to only those triangles
    oespicoli.OESurfaceCropToClique(surf, 1)

    # nlqs is the number of different connected components
    nclqs = oespicoli.OEMakeConnectedSurfaceCliques(surf)

    # Find the largest component
    maxclq = 0
    maxarea = 0.0
    for i in range(nclqs):
        area = oespicoli.OESurfaceCliqueArea(surf, i+1)
        print("clique: %d  area: %f" % (i+1, area))
        if (area > maxarea):
            maxclq = i+1
            maxarea = area

    # Crop to it
    oespicoli.OESurfaceCropToClique(surf, maxclq)

    oespicoli.OEWriteSurface(args[2], surf)

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oeszybki


def main(argv=[__name__]):
    szOpts = oeszybki.OELigandEntropyOptions()
    opts = oechem.OESimpleAppOptions(szOpts, "LigandEntropy", oechem.OEFileStringType_Mol3D,
                                     oechem.OEFileStringType_Mol3D)
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    szOpts.UpdateValues(opts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    for mol in ifs.GetOEMols():
        oechem.OEThrow.Info("Title: %s" % mol.GetTitle())
        res = oeszybki.OEEntropyResults()
        ret_code = oeszybki.OELigandEntropy(res, mol, szOpts)
        if ret_code == oeszybki.OESzybkiReturnCode_Success:
            oechem.OEThrow.Info("  Configurational Entropy: %0.2f" % res.GetConfigurationalEntropy())
            oechem.OEThrow.Info("  Solvation Entropy: %0.2f" % res.GetSolvationEntropy())
            oechem.OEThrow.Info("  Total Entropy: %0.2f" % res.GetTotalEntropy())
        else:
            oechem.OEThrow.Warning("Failed: %s" % oeszybki.OEGetSzybkiError(ret_code))
    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oeszybki


def main(args):
    if len(args) != 4:
        oechem.OEThrow.Usage("%s ligand_file protein_file output_file (SDF or OEB)" % args[0])

    lfs = oechem.oemolistream()
    if not lfs.open(args[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % args[1])

    pfs = oechem.oemolistream()
    if not pfs.open(args[2]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % args[2])

    ofs = oechem.oemolostream()
    if not ofs.open(args[3]):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % args[3])

    if not oechem.OEIsSDDataFormat(ofs.GetFormat()):
        oechem.OEThrow.Fatal("Output file does not support SD data used by this example")

    # Szybki options for VdW-Coulomb calculations
    optsC = oeszybki.OESzybkiOptions()
    optsC.GetProteinOptions().SetProteinElectrostaticModel(
                              oeszybki.OEProteinElectrostatics_ExactCoulomb)
    optsC.SetRunType(oeszybki.OERunType_CartesiansOpt)

    # Szybki options for PB calculations
    optsPB = oeszybki.OESzybkiOptions()
    optsPB.GetProteinOptions().SetProteinElectrostaticModel(
                               oeszybki.OEProteinElectrostatics_SolventPBForces)
    optsPB.SetRunType(oeszybki.OERunType_SinglePoint)

    # Szybki objects
    szC = oeszybki.OESzybki(optsC)
    szPB = oeszybki.OESzybki(optsPB)

    # read and setup protein
    protein = oechem.OEGraphMol()
    oechem.OEReadMolecule(pfs, protein)
    szC.SetProtein(protein)
    szPB.SetProtein(protein)

    terms = set([oeszybki.OEPotentialTerms_ProteinLigandInteraction,
                 oeszybki.OEPotentialTerms_VdWProteinLigand,
                 oeszybki.OEPotentialTerms_CoulombProteinLigand,
                 oeszybki.OEPotentialTerms_ProteinDesolvation,
                 oeszybki.OEPotentialTerms_LigandDesolvation,
                 oeszybki.OEPotentialTerms_SolventScreening])

    # process molecules
    for mol in lfs.GetOEMols():

        # optimize mol
        if not list(szC(mol)):
            oechem.OEThrow.Warning("No results processing molecule: %s" % mol.GetTitle())
            continue

        # do single point with better electrostatics
        for conf, results in zip(mol.GetConfs(), szPB(mol)):
            for i in terms:
                strEnergy = ("%9.4f" % results.GetEnergyTerm(i))
                oechem.OEAddSDData(conf, oeszybki.OEGetEnergyTermName(i), strEnergy)

        oechem.OEWriteMolecule(ofs, mol)

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))
